==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ColumnSupportingCalculationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnSupportingCalculationDescription } from "./ColumnSupportingCalculationDescription";
/**
 * @hidden
 */
var ColumnSupportingCalculationDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColumnSupportingCalculationDescriptionMetadata, _super);
    function ColumnSupportingCalculationDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColumnSupportingCalculationDescriptionMetadata.b = function (a) {
        if (ColumnSupportingCalculationDescriptionMetadata.a == null) {
            ColumnSupportingCalculationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColumnSupportingCalculationDescriptionMetadata.c(ColumnSupportingCalculationDescriptionMetadata.a);
        }
        if (a.g(ColumnSupportingCalculationDescriptionMetadata.a)) {
            return;
        }
        a.s(ColumnSupportingCalculationDescriptionMetadata.a);
    };
    ColumnSupportingCalculationDescriptionMetadata.c = function (a) {
    };
    ColumnSupportingCalculationDescriptionMetadata.d = function (a) {
        ColumnSupportingCalculationDescriptionMetadata.b(a);
        a.u("ColumnSupportingCalculation", function () { return new ColumnSupportingCalculationDescription(); });
        a.t("ColumnSupportingCalculation", ColumnSupportingCalculationDescriptionMetadata.a);
    };
    ColumnSupportingCalculationDescriptionMetadata.$t = markType(ColumnSupportingCalculationDescriptionMetadata, 'ColumnSupportingCalculationDescriptionMetadata');
    ColumnSupportingCalculationDescriptionMetadata.a = null;
    return ColumnSupportingCalculationDescriptionMetadata;
}(Base));
export { ColumnSupportingCalculationDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ColumnSupportingCalculationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnSupportingCalculationDescription } from "./ColumnSupportingCalculationDescription";
/**
 * @hidden
 */
var ColumnSupportingCalculationDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColumnSupportingCalculationDescriptionMetadata, _super);
    function ColumnSupportingCalculationDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColumnSupportingCalculationDescriptionMetadata.b = function (a) {
        if (ColumnSupportingCalculationDescriptionMetadata.a == null) {
            ColumnSupportingCalculationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColumnSupportingCalculationDescriptionMetadata.c(ColumnSupportingCalculationDescriptionMetadata.a);
        }
        if (a.j(ColumnSupportingCalculationDescriptionMetadata.a)) {
            return;
        }
        a.y(ColumnSupportingCalculationDescriptionMetadata.a);
    };
    ColumnSupportingCalculationDescriptionMetadata.c = function (a) {
    };
    ColumnSupportingCalculationDescriptionMetadata.d = function (a) {
        ColumnSupportingCalculationDescriptionMetadata.b(a);
        a.aa("ColumnSupportingCalculation", function () { return new ColumnSupportingCalculationDescription(); });
        a.z("ColumnSupportingCalculation", ColumnSupportingCalculationDescriptionMetadata.a);
    };
    ColumnSupportingCalculationDescriptionMetadata.$t = markType(ColumnSupportingCalculationDescriptionMetadata, 'ColumnSupportingCalculationDescriptionMetadata');
    ColumnSupportingCalculationDescriptionMetadata.a = null;
    return ColumnSupportingCalculationDescriptionMetadata;
}(Base));
export { ColumnSupportingCalculationDescriptionMetadata };
